pub enum CallbackHook {
Start,
FrameEnd,
IterationEnd,
Finish,
}Expand description
Point in runner execution at which a callback can be invoked.
Variants
Start
Once after initialization and before the first scheduled frame.
FrameEnd
After a processed acquisition frame when frame callbacks are enabled.
IterationEnd
After every complete acquisition schedule pass.
Finish
Once after a crate::reconstruction::ReconstructionResult is assembled.