pub struct SaveResidualsEvery { /* private fields */ }Expand description
Periodically saves one signed intensity-residual PNG per measured frame.
Each image is scaled symmetrically around zero so mid-gray represents zero, dark pixels are negative residuals, and bright pixels are positive residuals.
Implementations